package util;

import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class StringUtil {
	final static String METHOD_SET = "set";
	final static String METHOD_GET = "get";

	/**
	 * 笨方法：String s = "你要去除的字符串"; <br>
	 * 1.去除空格：s = s.replace('\\s',''); <br>
	 * 2.去除回车：s =s.replace('\n',''); 这样也可以把空格和回车去掉，其他也可以照这样做。<br>
	 * 注：\n 回车 \t 水平制表符 \s空格 \r 换行
	 * 
	 * @param str
	 * @return
	 */
	public static String replaceBlank(String str) {
		String dest = "";
		if (str != null) {
			Pattern p = Pattern.compile("\\s*|\t|\r|\n");
			Matcher m = p.matcher(str);
			dest = m.replaceAll("");
		}
		return dest;
	}

	/**
	 * 将特殊字符转义再切分
	 * 
	 * @param source
	 * @param spliter
	 * @return
	 */
	public static String[] splitStr2Array(String source, String spliter) {

		String regex = spliter;
		if (regex.equals("?") || regex.equals("*") || regex.equals(")") || regex.equals("(") || regex.equals("{") || regex.equals("$") || regex.equals("+") || regex.equals(".") || regex.equals("|")) {

			regex = "[" + regex + "]";
		}

		return source.split(regex);
	}

	/**
	 * 将byte[] 转换成字符串
	 * @param srcBytes
	 * @return
     */
	public static String byte2Hex(byte[] srcBytes) {
		StringBuilder hexRetSB = new StringBuilder();
		for (byte b : srcBytes) {
			String hexString = Integer.toHexString(0x00ff & b);
			hexRetSB.append(hexString.length() == 1 ? 0 : "").append(hexString);
		}
		return hexRetSB.toString();
	}

	/**
	 * 将16进制字符串转为转换成字符串
	 * 
	 * @param source
	 * @return
	 */
	public static byte[] hex2Bytes(String source) {
		byte[] sourceBytes = new byte[source.length() / 2];
		for (int i = 0; i < sourceBytes.length; i++) {
			sourceBytes[i] = (byte) Integer.parseInt(source.substring(i * 2, i * 2 + 2), 16);
		}
		return sourceBytes;
	}

	/**
	 * 请求参数明文拼接
	 * @param method 请求方法
	 * @param version 版本号
	 * @param format 请求格式
	 * @param merchantNo 商户号
	 * @param signType 加密类型
	 * @param signContent 请求报文明文
	 * @param key 签名混淆key，平台分配
	 * @return
	 */
	public static String reqSingStr(String method,String version,String format,String merchantNo,String signType,String signContent,String key){
		StringBuilder signStr = new StringBuilder();
		signStr.append("method=");
		signStr.append(method);
		signStr.append("&version=");
		signStr.append(version);
		signStr.append("&format=");
		signStr.append(format);
		signStr.append("&merchantNo=");
		signStr.append(merchantNo);
		signStr.append("&signType=");
		signStr.append(signType);
		signStr.append("&signContent=");
		signStr.append(signContent);
		signStr.append("&key=");
		signStr.append(key);
		return signStr.toString();
	}

	/**
	 *
	 * 响应明文拼接
	 */
	public static String resSingStr(Map<String,Object> respMap, String key){

		StringBuilder signStr = new StringBuilder();
		if(respMap.get("success").toString().equals("true") ){
			signStr.append("result=");
			signStr.append(respMap.get("result"));
			signStr.append("&success=");
			signStr.append(respMap.get("success"));
			signStr.append("&key=");
			signStr.append(key);
		}
		else {
			signStr.append("errorCode=" + respMap.get("errorCode"));
			signStr.append("&errorMsg=" + respMap.get("errorMsg"));
			signStr.append("&success=" + respMap.get("success"));
			signStr.append("&key=" + key);
		}
		return signStr.toString();
	}
}
